.. piqueserver documentation master file, created by
   sphinx-quickstart on Sat Dec 30 14:31:44 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to piqueserver's documentation!
=======================================

Piqueserver is an Ace of Spades 0.75 Server based on Pysnip.

.. toctree::
   :maxdepth: 1
   :caption: Administrator Resources

   installation
   configuration
   supported-python-environments
   included-scripts
   included-gamemodes
   command-line
   docker
   systemd-install-setup

.. toctree::
   :maxdepth: 1
   :caption: Developer Resources

   porting

   contributing-developer
   architecture
   startup-and-initialization

   release-guide

   piqueserver
   pyspades


.. toctree::
   :maxdepth: 1
   :caption: Miscellaneous

   contributing
   Network ports list (useful for firewall configuration) <network-ports>
   A list of somewhat relevant pyspades forks <pyspades-forks-nota-list>

Technical details
-----------------

- (TODO) Technical details: aimbot detection
- `Technical details: AoS 0.75 protocol <https://piqueserver.github.io/aosprotocol/>`_

External tools
--------------

- `aos-to-address <https://noway.github.io/aos-to-address/>`_ by noway421 - Convert AoS URIs to their respective IP addresses

.. note::

   The `PySpades wiki <https://github.com/infogulch/pyspades/wiki>`_ has some legacy information that might be helpful.

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
